==> haskell-lsp1.4-1.4.0.0-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp
version:              1.4.0.0
visibility:           public
id:                   lsp-1.4.0.0-3iWLxxsNkye2cyDEWOnWvW
key:                  lsp-1.4.0.0-3iWLxxsNkye2cyDEWOnWvW
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  2857082d9afa5aa77720cb16ff7222dc
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Server,
    Language.LSP.Types from lsp-types-1.4.0.1-1mjp4sVxmhFKUhIla2w89o:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-1mjp4sVxmhFKUhIla2w89o:Language.LSP.Types.Capabilities,
    Language.LSP.Types.Lens from lsp-types-1.4.0.1-1mjp4sVxmhFKUhIla2w89o:Language.LSP.Types.Lens,
    Language.LSP.VFS from lsp-types-1.4.0.1-1mjp4sVxmhFKUhIla2w89o:Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Core Language.LSP.Server.Control
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-1.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp1.4
hs-libraries:         HSlsp-1.4.0.0-3iWLxxsNkye2cyDEWOnWvW
depends:
    aeson-2.1.2.1-F86TtVKFNKJLpW409aVG0j
    async-2.2.5-L1pFc6v09ikFDHHjgXlurp
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB exceptions-0.10.4
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hslogger-1.3.1.0-LGXq0Irhzb534fxuYt7u8c
    lens-5.2.3-KEHbFlXppcrGAx1vZwwIkx
    lsp-types-1.4.0.1-1mjp4sVxmhFKUhIla2w89o mtl-2.2.2
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR
    sorted-list-0.2.2.0-41XPxeYLLUnGQeEO6eeM9Z stm-2.5.0.2 text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    uuid-1.3.15-sDtC8PfuMJ4kPM3zoEG7

haddock-interfaces:   /usr/share/doc/haskell-lsp1.4/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp1.4/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lsp1.4-1.4.0.0-93-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lsp1.4.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lsp
version:              1.4.0.0
visibility:           public
id:                   lsp-1.4.0.0-Kh3MoMtE3kU14IoD0s3bd7
key:                  lsp-1.4.0.0-Kh3MoMtE3kU14IoD0s3bd7
license:              MIT
copyright:            Alan Zimmerman, 2016-2021
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman
homepage:             https://github.com/haskell/lsp
synopsis:             Haskell library for the Microsoft Language Server Protocol
description:
    An implementation of the types, and basic message server to
    allow language implementors to support the Language Server
    Protocol for their specific language.

    An example of this is for Haskell via the Haskell Language
    Server, at https://github.com/haskell/haskell-language-server

category:             Development
abi:                  77dd48fbd67612a98bc93821b42cee0c
exposed:              True
exposed-modules:
    Language.LSP.Diagnostics, Language.LSP.Server,
    Language.LSP.Types from lsp-types-1.4.0.1-5dixMEkuYn0BXFxok5s0Hw:Language.LSP.Types,
    Language.LSP.Types.Capabilities from lsp-types-1.4.0.1-5dixMEkuYn0BXFxok5s0Hw:Language.LSP.Types.Capabilities,
    Language.LSP.Types.Lens from lsp-types-1.4.0.1-5dixMEkuYn0BXFxok5s0Hw:Language.LSP.Types.Lens,
    Language.LSP.VFS from lsp-types-1.4.0.1-5dixMEkuYn0BXFxok5s0Hw:Language.LSP.VFS

hidden-modules:
    Language.LSP.Server.Core Language.LSP.Server.Control
    Language.LSP.Server.Processing

import-dirs:          /usr/lib/ghc-9.2.8/site-local/lsp-1.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/lsp-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lsp1.4
hs-libraries:         HSlsp-1.4.0.0-Kh3MoMtE3kU14IoD0s3bd7
depends:
    aeson-2.1.2.1-3YQjfXPQMsb4U9de9kBzUF
    async-2.2.5-L1pFc6v09ikFDHHjgXlurp
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1
    data-default-0.7.1.1-LSJh75QrCu1H2SWBLBb1YB exceptions-0.10.4
    hashable-1.4.3.0-4gqtyFKn8Wu9OwsZtyYGdt
    hslogger-1.3.1.0-LGXq0Irhzb534fxuYt7u8c
    lens-5.2.3-CoPC409lmbd4eaEH6bTfXB
    lsp-types-1.4.0.1-5dixMEkuYn0BXFxok5s0Hw mtl-2.2.2
    network-uri-2.6.4.2-BteEq2hoHgh9OCrkgJDHXL
    random-1.2.1.2-LCKSS7rEcRbACR8x8dKjFH
    scientific-0.3.7.0-72r9rPpXaeUjwM4XNBSJR
    sorted-list-0.2.2.0-41XPxeYLLUnGQeEO6eeM9Z stm-2.5.0.2 text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn
    unordered-containers-0.2.20-3nVNqHdmWG59aZRDnxmFox
    uuid-1.3.15-sDtC8PfuMJ4kPM3zoEG7

haddock-interfaces:   /usr/share/doc/haskell-lsp1.4/html/lsp.haddock
haddock-html:         /usr/share/doc/haskell-lsp1.4/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
